summaryrefslogtreecommitdiffstats
path: root/kpresenter/KPrCanvas.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:32:11 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:32:11 -0600
commit94844816550ad672ccfcdc25659c625546239998 (patch)
treee35fc60fd736c645d59f6408af032774ad8023d3 /kpresenter/KPrCanvas.h
parent2a811c38c74c03648ecf857e566c44483cbad706 (diff)
downloadkoffice-94844816550ad672ccfcdc25659c625546239998.tar.gz
koffice-94844816550ad672ccfcdc25659c625546239998.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'kpresenter/KPrCanvas.h')
-rw-r--r--kpresenter/KPrCanvas.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kpresenter/KPrCanvas.h b/kpresenter/KPrCanvas.h
index e2b373e1..2d8c7f48 100644
--- a/kpresenter/KPrCanvas.h
+++ b/kpresenter/KPrCanvas.h
@@ -360,7 +360,7 @@ exportPage( 0, s, 800, 600, "/home/khz/page0.png", "PNG", 100 );
TQPixmap getPicturePixmap() const;
void closeObject(bool _close);
- void tqlayout();
+ void layout();
void alignVertical(VerticalAlignmentType _type );
void savePicture();
@@ -376,8 +376,8 @@ exportPage( 0, s, 800, 600, "/home/khz/page0.png", "PNG", 100 );
void objectPopup( KPrObject *object, const TQPoint &point );
public slots:
- // use tqrepaint = false when the KPrCanvas is destroyed to avaid a possible crash
- void exitEditMode( bool tqrepaint = true );
+ // use repaint = false when the KPrCanvas is destroyed to avaid a possible crash
+ void exitEditMode( bool repaint = true );
void clipCut();
void clipCopy();
@@ -543,9 +543,9 @@ protected:
TQRect getPageRect( bool decBorders = true ) const;
unsigned int pageNums() const;
- void _tqrepaint( bool erase=true );
- void _tqrepaint( const TQRect &r );
- void _tqrepaint( KPrObject *o );
+ void _repaint( bool erase=true );
+ void _repaint( const TQRect &r );
+ void _repaint( KPrObject *o );
/**
* Draw page defined in step to painter.
@@ -633,7 +633,7 @@ private:
/// resize the m_resizeObject
void resizeObject( ModifyType _modType, const KoPoint & point, bool keepRatio, bool scaleAroundCenter );
/// create KPrResizeCmd
- void finishResizeObject( const TQString &name, bool tqlayout = true );
+ void finishResizeObject( const TQString &name, bool layout = true );
/**
* @brief Display object above the other objects in editiong mode
@@ -692,7 +692,7 @@ private:
* @param pos the point which should be snapped
* @param repaintSnapping true if the guides should be repainted.
* @param repaintSnapping false when the guides should not be repainted.
* You have to call tqrepaint by yourself.
*
* @return the position of the snapped point
*/
@@ -692,7 +692,7 @@ private:
* @param repaintSnapping true if the guides should be repainted.
* @param repaintSnapping false when the guides should not be repainted.
- * You have to call tqrepaint by yourself.
+ * You have to call repaint by yourself.
*
* @return the position of the snapped point